"""
Trading prompts module initialization.
"""

from mcp_paradex.prompts.trader_prompts import (
    create_optimal_order,
    funding_rate_opportunity,
    getting_started,
    hedging_strategy,
    liquidation_protection,
    market_analysis,
    market_overview,
    portfolio_risk_assessment,
    position_management,
    trading_consultation,
    vault_analysis,
)

__all__ = [
    "create_optimal_order",
    "funding_rate_opportunity",
    "getting_started",
    "hedging_strategy",
    "liquidation_protection",
    "market_analysis",
    "market_overview",
    "portfolio_risk_assessment",
    "position_management",
    "trading_consultation",
    "vault_analysis",
]
